@@ -44,6 +44,11 @@ namespace facter { namespace facts { namespace external {
          * @param facts The fact collection to populate the external facts into.
          */
         virtual void resolve(std::string const& path, collection& facts) const = 0;
+
+        /**
+         * Destructor for external resolver.
+         */
+        virtual ~resolver() {}
     };
 
 }}}  // namespace facter::facts::external
