@@ -426,6 +426,26 @@ namespace facter { namespace facts {
          */
         constexpr static char const* macosx_productversion_minor = "macosx_productversion_minor";
 
+        /**
+        * The fact for Windows to specify if is Server or Desktop Edition variant
+        */
+        constexpr static char const* windows_edition_id = "windows_edition_id";
+
+        /**
+        * The fact for Windows to differentiate Server, Server Core, Client (Desktop)
+        */
+        constexpr static char const* windows_installation_type = "windows_installation_type";
+
+        /**
+        * The fact for Windows textual product name
+        */
+        constexpr static char const* windows_product_name = "windows_product_name";
+
+        /**
+         * The fact for Windows Build Version.
+         */
+        constexpr static char const* windows_release_id = "windows_release_id";
+
         /**
          * The fact for Windows native system32 directory.
          */
@@ -439,7 +459,14 @@ namespace facter { namespace facts {
          * The fact for whether or not the machine is virtual or physical.
          */
         constexpr static char const* is_virtual = "is_virtual";
-
+        /**
+         * The fact for all detected hypervisors
+         */
+        constexpr static char const* hypervisors = "hypervisors";
+        /**
+         * The fact for the cloud info, including provider, for a node.
+         */
+        constexpr static char const* cloud = "cloud";
         /**
          * The structured fact for identity information.
          */
@@ -524,9 +551,9 @@ namespace facter { namespace facts {
         constexpr static char const* zfs_version = "zfs_version";
 
         /**
-         * The ZFS supported feature numbers.
+         * The ZFS supported version numbers.
          */
-        constexpr static char const* zfs_featurenumbers = "zfs_featurenumbers";
+        constexpr static char const* zfs_versionnumbers = "zfs_featurenumbers";
 
         /**
          * The ZFS storage pool (zpool) version fact.
@@ -534,9 +561,14 @@ namespace facter { namespace facts {
         constexpr static char const* zpool_version = "zpool_version";
 
         /**
-         * The ZFS storage pool supported feature numbers.
+         * The ZFS storage pool supported feature flags.
          */
-        constexpr static char const* zpool_featurenumbers = "zpool_featurenumbers";
+        constexpr static char const* zpool_featureflags = "zpool_featureflags";
+
+        /**
+         * The ZFS storage pool supported version numbers.
+         */
+        constexpr static char const* zpool_versionnumbers = "zpool_featurenumbers";
 
         /**
          * The fact for number of Solaris zones.
@@ -642,6 +674,21 @@ namespace facter { namespace facts {
          * The fact for Xen domains.
          */
         constexpr static char const* xendomains = "xendomains";
+
+        /**
+         * The structured fact for Solaris LDom facts.
+         */
+        constexpr static char const* ldom = "ldom";
+
+        /**
+         * The fips mode fact for RHEL/Linux* facts.
+         */
+        constexpr static char const* fips_enabled = "fips_enabled";
+
+        /**
+         * The fact for Aix NIM type (master/client)
+         */
+        constexpr static char const* nim_type = "nim_type";
     };
 
 }}  // namespace facter::facts
